# Softweb Solutions Inc
## IOT Connect SDK : Software Development Kit 2.0.6

**Prerequisite tools:**

1. Java 8 ( or above )
2. Android SDK
3. Android Studio

**Installation:** 

1. You can directly import the sdk package from gradle URL

2. Please verify jcenter in your root build.gradle at the end of repositories.
```java
	allprojects {
		repositories {
			...
			 jcenter()
		}
	}
```

3. Add below dependency.
```java
	dependencies {
		implementation 'com.iotconnectsdk:iotconnectpoc:2.0.6'			
	}
```

**Usage :**

- Prerequisite standard input data.
```java  	
	//Get your environment and cpId from the portal key vaults module or visit https://help.iotconnect.io SDK section
	uniqueId = <<uniqueId>>;
	cpId = <<CPID>>; 
	environment = <<environment>>; 
```

- To Initialize the SDK object and get the device information to connect to the device with IoTConnect cloud.
```java
	IoTConnectSDK ioTConnectSDK = new IoTConnectSDK(Activity.this, cpId, uniqueId, IotSDKCallback, environment);
```

- Implement methods to receive the command from Cloud to Device(C2D)
```java
	IotSDKCallback 	// To receive the command from Cloud to Device(C2D).
	
	//Command receive from Cloud to Device(C2D).

	@Override
	public void onReceiveMsg(String message) {
        if (!message.isEmpty()) {
			JSONObject mainObject = new JSONObject(message);
			String cmdType = mainObject.getString("cmdType");
			JSONObject dataObj = mainObject.getJSONObject("data");
			
			switch (cmdType) {
				case "0x01":
					// Device Command
				break;

				case "0x02":
					// Firmware Command
				break;
			}
		}
	}
```

- This is the standard data input format to send the data
```json
	data = [{
		"uniqueId": "<< Device UniqueId >>",
		"time" : "<< date >>", //Date format should be as defined
		"data": {} // example : {"temperature": 15.55, "gyroscope" : { 'x' : -1.2 }}
	}];
```

- To send the data from Device To Cloud(D2C)
```java
	iotConnectSDK.sendData(data);
```

- To get attributes.
```java
	@Override
    public void attributeData(List<SyncServiceResponse.DBeanXX.AttBean> attributesBeanList) {
		Log.d(TAG,data);
	}
```	

- To get connection status
```java
	@Override
    public void onConnectionStateChange(boolean isConnected) {
        if (isConnected) {
            //device connected 
        } else {
			//device not connected
        }
    }
```

- To send the command acknowledgment
```java
	JSONObject obj = new JSONObject("{
		"ackId": "",
		"st": "",
		"msg": "",
		"childId": ""
	}");
	String messageType = "";
	ioTConnectSDK.sendAck(JSONObject obj, String messageType)
```	
- ackId(*) : Command ack guId which is receive from command payload
- st(*) : Acknowledgment status sent to cloud (4 = Fail, 6 = Device command[0x01], 7 = Firmware OTA command[0x02])
- msg : Message 
- childId : Leave it blank("")
- msgType : Message type (5 = "0x01" device command, 11 = "0x02" Firmware OTA command)
Note : (*) indicates the mandatory element of the object.

- To disconnect the device from the cloud	
```java	
	ioTConnectSDK.disconnectSDK();
```

- Disconnect iotConnect on Activity onDestroy
```java	
	
	@Override
    protected void onDestroy() {
        super.onDestroy();
        if (ioTConnectSDK != null) {
            ioTConnectSDK.disconnectSDK();
        }
    }
```